@@ -2,7 +2,7 @@
 
 =head1 NAME
 
-Slaughter::Info::openbsd - Perl Automation Tool Helper OpenBSD info implementation
+Slaughter::Info::openbsd - Determine information about an OpenBSD host.
 
 =cut
 
@@ -18,7 +18,17 @@ the current host.
 This module is loaded only on OpenBSD systems, and will determine such details
 as the local hostname, the free RAM, any IP addresses, etc.
 
-Usage is:
+The correct information-gathering module is loaded at run-time via the use of the C<$^O> variable, and if no system-specific module is available then the generic L<Slaughter::Info::generic> module is used as a fall-back.
+
+The information discovered can be dumped by running C<slaughter>
+
+=for example begin
+
+      ~# slaughter --dump
+
+=for example end
+
+Usage of this module is as follows:
 
 =for example begin
 
@@ -59,7 +69,7 @@ package Slaughter::Info::openbsd;
 #
 # The version of our release.
 #
-our $VERSION = "3.0.2";
+our $VERSION = "3.0.3";
 
 
 
